abort_status: Informative 'stop_for_status()' Wrapper

Description Usage Arguments Value

View source: R/utils.R

Description

abort_status() is just like stop_for_status(), except it prints the response message returned by the server on error (if any).

Usage

1
abort_status(x, task = "complete request")

Arguments

x

A response object

task

character. A message to display to the use as "Failed to task"

Value

If request was successful, the response (invisibly). Otherwise, raised a classed http error, as generated by http_condition()


jesse-smith/essence documentation built on Dec. 20, 2021, 11:05 p.m.