check_datasource: Check/Assert that an Input is a Valid ESSENCE Datasource...

Description Usage Arguments Value

View source: R/utils-check_essence.R

Description

Check/Assert that an Input is a Valid ESSENCE Datasource String

Usage

1
2
3
4
5
6
7
8
check_datasource(datasource, creds = es_creds_get(), fmatch = TRUE)

assert_datasource(
  datasource,
  creds = es_creds_get(),
  fmatch = TRUE,
  add = NULL
)

Arguments

creds

secret. User login credentials for ESSENCE.

fmatch

[logical(1)]
Use the set operations implemented in fmatch in package fastmatch. If fastmatch is not installed, this silently falls back to match. fmatch modifies y by reference: A hash table is added as attribute which is used in subsequent calls.

add

[AssertCollection]
Collection to store assertion messages. See AssertCollection.

Value

check_*() returns TRUE if successful or a error message string otherwise; assert_*() returns x (invisibly) if successful or an error otherwise


jesse-smith/essence documentation built on Dec. 20, 2021, 11:05 p.m.