check_ts_query: Check TimeSeries Query Arguments

Description Usage Arguments Value

View source: R/es_ts.R

Description

Check TimeSeries Query Arguments

Usage

1
2
3
4
5
6
7
8
check_ts_query(
  datasource,
  startDate,
  endDate,
  timeResolution,
  dots,
  creds = es_creds_get()
)

Arguments

datasource

[character(1)] An ESSENCE data source; see es_datasource() for available options

startDate

[Date(1)] or an object that can be coerced to one. The start date for the query.

endDate

[Date(1)] or an object that can be coerced to one. The end date for the query.

timeResolution

[character(1)]. The resolution of the returned timeseries.

dots

Additional query parameters; see the ESSENCE User Guide (in particular the API section) for details. All arguments must be named.

creds

secret. User login credentials for ESSENCE.

Value

TRUE (invisibly) if assertions are passed


jesse-smith/essence documentation built on Dec. 20, 2021, 11:05 p.m.