es_ts_query: Create an ESSENCE TimeSeries Query

Description Usage Arguments Value

View source: R/es_ts.R

Description

Create an ESSENCE TimeSeries Query

Usage

1
2
3
4
5
6
7
8
9
es_ts_query(
  datasource,
  startDate,
  endDate,
  timeResolution,
  ...,
  creds = es_creds_get(),
  check = TRUE
)

Arguments

datasource

[character(1)] An ESSENCE data source; see es_datasource() for available options

startDate

[Date(1)] or an object that can be coerced to one. The start date for the query.

endDate

[Date(1)] or an object that can be coerced to one. The end date for the query.

timeResolution

[character(1)]. The resolution of the returned timeseries.

...

Additional query parameters; see the ESSENCE User Guide (in particular the API section) for details. All arguments must be named.

creds

secret. User login credentials for ESSENCE.

check

[logical(1)] Should the query parameters be checked before requesting? Note that some timeseries-specific parameters (e.g. detector) will currently cause an error.

Value

A string containing the URL query parameters to pass to es_GET()


jesse-smith/essence documentation built on Dec. 20, 2021, 11:05 p.m.